@@ -4,15 +4,23 @@ Implements several classes to interact with all types of Deezer objects,
 do some searches, and build application written in Python on top of it
 
 """
-from deezer.asynchronous import AsyncClient
 from deezer.client import Client
 from deezer.resources import Album, Resource, Artist, Playlist
 from deezer.resources import Genre, Track, User, Comment, Radio
 
 
-__version__ = '0.7.0'
-__all__ = ['AsyncClient', 'Client', 'Resource', 'Album',
-           'Artist', 'Genre', 'Playlist', 'Track', 'User',
-           'Comment', 'Radio']
+__version__ = "0.9.0"
+__all__ = [
+    "Client",
+    "Resource",
+    "Album",
+    "Artist",
+    "Genre",
+    "Playlist",
+    "Track",
+    "User",
+    "Comment",
+    "Radio",
+]
 
-USER_AGENT = 'Deezer Python API Wrapper v{0}'.format(__version__)
+USER_AGENT = "Deezer Python API Wrapper v{0}".format(__version__)
